#
# spec file for package mingw32-binutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mingw32-binutils
Version:        2.42
Release:        1.2
Summary:        GNU Binutils
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries
URL:            http://www.gnu.org/software/binutils/
Source:         http://ftp.gnu.org/gnu/binutils/binutils-%{version}.tar.xz
Source1:        http://ftp.gnu.org/gnu/binutils/binutils-%{version}.tar.xz.sig
Source2:        mingw32-binutils.keyring
Source99:       mingw32-binutils-rpmlintrc
Patch0:         binutils-2.42-option-high-entry-va.patch
#!BuildIgnore: post-build-checks
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  mingw32-cross-binutils
BuildRequires:  mingw32-cross-gcc
BuildRequires:  mingw32-filesystem
BuildRequires:  texinfo
BuildArch:      noarch
%_mingw32_package_header_debug

%description
The GNU Binutils are a collection of binary tools.
These utilities (like 'as', 'ld', 'strip') understand Windows executables and DLLs.

%package devel
Summary:        %{summary}
Group:          Development/Libraries

%description devel
libbfd, libiberty and libopcodes.a

%_mingw32_debug_package

%prep
%autosetup -p1 -n binutils-%{version}

%build
mkdir -p build
cd build
%{_mingw32_configure} \
  --verbose --disable-nls \
  --without-included-gettext \
  --disable-win32-registry \
  --with-sysroot=%{_mingw32_prefix} \
  --disable-werror \
  --enable-install-libiberty

%make_build || make

%install
cd build
%make_install

rm -f %{buildroot}%{_mingw32_infodir}/dir

# mingw32-binutils.noarch: E: zero-length .../lib/ldscripts/stamp
for i in %{buildroot}%{_mingw32_prefix}/%{_mingw32_target}/lib/ldscripts/stamp; do
  if test -f $i; then
    rm $i
  fi
done

%files
%{_mingw32_bindir}/*.exe
%{_mingw32_prefix}/%{_mingw32_target}/bin/*.exe
%{_mingw32_prefix}/%{_mingw32_target}/lib/ldscripts/
%dir %{_mingw32_prefix}/lib/bfd-plugins/
%{_mingw32_prefix}/lib/bfd-plugins/libdep.dll
%{_mingw32_mandir}/man1/*
%{_mingw32_infodir}/*.info*

%files devel
%{_mingw32_includedir}/
%{_mingw32_libdir}/libbfd.a
%{_mingw32_libdir}/libctf.a
%{_mingw32_libdir}/libctf-nobfd.a
# required by libbfd.a
%{_mingw32_libdir}/libiberty.a
%{_mingw32_libdir}/libopcodes.a
%{_mingw32_libdir}/libsframe.a

%changelog
* Thu Jun 20 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Fixes:
  * mingw32-binutils.spec: W: patch-fuzz-is-changed
  * "mingw32-binutils.keyring" is not mentioned in spec files as
    source or patch
  * mingw32-binutils.noarch: E: zero-length
    /usr/i686-w64-mingw32/sys-root/mingw/lib/ldscripts/stamp
  * mingw32-binutils.src: E: unused-rpmlintrc-filter
    "arch-independent-package-contains-binary-or-object"
* Sat Jun 15 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Fix "binutils-2.42.tar.xz.sig" is not mentioned in spec files as
  source or patch.
* Mon Jun  3 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 2.42
- Add mingw32-binutils.keyring
- Removed patches that were included in the official version
  * 0001-dllwrap-windres-and-dlltools-use-mktemp-which-should.patch
  * 0001-Fix-bug-not-showing-correct-path-with-objdump-WL-wit.patch
  * 0001-PR29362-some-binutils-memory-leaks.patch
  * reproducible.patch
- Add patch
  * binutils-2.42-option-high-entry-va.patch
- Removed patch
  * binutils-2.39-option-high-entry-va.patch
* Fri May 31 2024 Ralf Habacker <ralf.habacker@freenet.de>
- Add patch to enable HEASLR with PE builds which is a leftover from
    https://sourceware.org/bugzilla/show_bug.cgi?id=19011 (boo#948280)
  * binutils-2.39-option-high-entry-va.patch
* Fri Oct  6 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to override build date (boo#1047218)
* Mon Aug 22 2022 Ralf Habacker <ralf.habacker@freenet.de>
- Update to version 2.39
- Add patch to fix memory leak in objdump bug, see
  https://sourceware.org/bugzilla/show_bug.cgi?id=29505 for details
  * 0001-PR29362-some-binutils-memory-leaks.patch
- Add patch to fix issue with objdump -WL, see
  https://sourceware.org/bugzilla/show_bug.cgi?id=29523
  * 0001-Fix-bug-not-showing-correct-path-with-objdump-WL-wit.patch
- Add patch to fix warning: 'call-to-mktemp ...'
  https://sourceware.org/bugzilla/show_bug.cgi?id=29534
  * 0001-dllwrap-windres-and-dlltools-use-mktemp-which-should.patch
* Wed Jun 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update to version 2.38
- Drop 0001-Fix-a-potential-infinite-loop-in-the-Windows-resourc.patch,
  0001-Fix-the-windmc-program-to-conform-to-the-behaviour-o.patch
* Tue Jun  9 2020 Ralf Habacker <ralf.habacker@freenet.de>
- Add patches to fix (boo#920134)
  * 0001-Fix-a-potential-infinite-loop-in-the-Windows-resourc.patch
  * 0001-Fix-the-windmc-program-to-conform-to-the-behaviour-o.patch
  (removed conflicting changelog entry)
* Sun Nov 24 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.33.1
- Drop 0001-COFF-Check-for-symbols-defined-in-discarded-section.patch
  Fixed upstream.
* Wed Nov 20 2019 Ludwig Nussel <lnussel@suse.de>
- inital package for Factory submission
